@@ -1,8 +1,6 @@
 from lightwood.api.dtype import dtype
 from lightwood.api.types import (
     JsonAI,
-    Output,
-    Feature,
     TypeInformation,
     StatisticalAnalysis,
     ProblemDefinition,
@@ -31,8 +29,6 @@ __all__ = [
     "code_from_json_ai",
     "json_ai_from_problem",
     "JsonAI",
-    "Output",
-    "Feature",
     "TypeInformation",
     "StatisticalAnalysis",
     "ProblemDefinition",
