@@ -5,7 +5,7 @@ from lightwood.encoder.datetime.datetime_sin_normalizer import DatetimeNormalize
 from lightwood.encoder.image.img_2_vec import Img2VecEncoder
 from lightwood.encoder.numeric.numeric import NumericEncoder
 from lightwood.encoder.numeric.ts_numeric import TsNumericEncoder
-from lightwood.encoder.numeric.ts_array_numeric import TsArrayNumericEncoder
+from lightwood.encoder.array.ts_num_array import TsArrayNumericEncoder
 from lightwood.encoder.text.short import ShortTextEncoder
 from lightwood.encoder.text.vocab import VocabularyEncoder
 from lightwood.encoder.text.rnn import RnnEncoder as TextRnnEncoder
@@ -13,13 +13,15 @@ from lightwood.encoder.categorical.onehot import OneHotEncoder
 from lightwood.encoder.categorical.binary import BinaryEncoder
 from lightwood.encoder.categorical.autoencoder import CategoricalAutoEncoder
 from lightwood.encoder.time_series.ts import TimeSeriesEncoder
-from lightwood.encoder.array.array import ArrayEncoder
+from lightwood.encoder.array.array import ArrayEncoder, NumArrayEncoder, CatArrayEncoder
 from lightwood.encoder.categorical.multihot import MultiHotEncoder
+from lightwood.encoder.array.ts_cat_array import TsCatArrayEncoder
 from lightwood.encoder.text.pretrained import PretrainedLangEncoder
 from lightwood.encoder.audio import MFCCEncoder
 
 
 __all__ = ['BaseEncoder', 'DatetimeEncoder', 'Img2VecEncoder', 'NumericEncoder', 'TsNumericEncoder',
            'TsArrayNumericEncoder', 'ShortTextEncoder', 'VocabularyEncoder', 'TextRnnEncoder', 'OneHotEncoder',
-           'CategoricalAutoEncoder', 'TimeSeriesEncoder', 'ArrayEncoder', 'MultiHotEncoder',
+           'CategoricalAutoEncoder', 'TimeSeriesEncoder', 'ArrayEncoder', 'MultiHotEncoder', 'TsCatArrayEncoder',
+           'NumArrayEncoder', 'CatArrayEncoder',
            'PretrainedLangEncoder', 'BinaryEncoder', 'DatetimeNormalizerEncoder', 'MFCCEncoder']
