@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Iterable
 import torch
 
 
@@ -39,16 +39,37 @@ class BaseEncoder:
         self.output_size = None
 
     # Not all encoders need to be prepared
-    def prepare(self, priming_data) -> None:
+    def prepare(self, priming_data: Iterable[object]) -> None:
+        """
+        Given 'priming_data' (i.e. training data), prepares encoders either through a rule-based (ex: one-hot encoding) or learned (ex: DistilBERT for text) model. This works explicitly on only training data.
+
+        :param priming_data: An iterable data structure where all the elements have type that is compatible with the encoder processing type; this may differ per encoder.
+        """ # noqa
         self.is_prepared = True
 
-    def encode(self, column_data) -> torch.Tensor:
+    def encode(self, column_data: Iterable[object]) -> torch.Tensor:
+        """
+        Given the approach defined in `prepare()`, encodes column data into a numerical representation to form part of the feature vector.
+
+        After all columns are featurized, each encoded vector is concatenated to form a feature vector per row in the dataset.
+
+        :param column_data: An iterable data structure where all the elements have type that is compatible with the encoder processing type; this may differ per encoder.
+
+        :returns: The encoded representation of data, per column
+        """ # noqa
         raise NotImplementedError
 
-    def decode(self, encoded_data) -> List[object]:
+    def decode(self, encoded_data: torch.Tensor) -> List[object]:
+        """
+        Given an encoded representation, returns the decoded value. Decoded values may not exist for all encoders (ex: rich text, audio, etc.)
+
+        :param encoded_data: The input representation in encoded format
+
+        :returns: The decoded representation of data, per column, in the original data-type presented.
+        """ # noqa
         raise NotImplementedError
 
-    # Should work for all torch-based encoders, but custom behavior may have to be implemented for weird models
+    # TODO Should work for all torch-based encoders, but custom behavior may have to be implemented for weird models
     def to(self, device, available_devices):
         # Find all nn.Module type objects and convert them
         # @TODO: Make this work recursively
