@@ -1,11 +1,9 @@
 from typing import Iterable
 
 
-def can_be_nan_numeric(value: object) -> bool:
+def is_nan_numeric(value: object) -> bool:
     """
     Determines if **value** might be `nan` or `inf` or some other numeric value (i.e. which can be cast as `float`) that is not actually a number.
-    
-    Name is vague due to uncertainty that all edge cases of numeric values that have number-like type behavior are covered.
     """  # noqa
 
     try:
@@ -24,4 +22,4 @@ def can_be_nan_numeric(value: object) -> bool:
 
 
 def filter_nan_and_none(series: Iterable) -> list:
-    return [x for x in series if not can_be_nan_numeric(x) and x is not None]
+    return [x for x in series if not is_nan_numeric(x) and x is not None]
