@@ -36,8 +36,8 @@ class TestTransformTS(unittest.TestCase):
 
         target = [i for i in range(data_len)]
         all_residuals, mean = get_naive_residuals(pd.DataFrame(target))
-        self.assertEqual(all_residuals, [1.0 for _ in range(data_len - 1)])
-        self.assertEqual(mean, 1)
+        self.assertEqual(all_residuals, [i for i in range(1, data_len)])
+        self.assertEqual(mean, np.mean([i for i in range(1, data_len)]))
 
         target = [0 for _ in range(data_len)]
         all_residuals, mean = get_naive_residuals(pd.DataFrame(target))
@@ -46,8 +46,8 @@ class TestTransformTS(unittest.TestCase):
 
         target = [1, 4, 2, 5, 3]
         all_residuals, mean = get_naive_residuals(pd.DataFrame(target))
-        self.assertEqual(all_residuals, [3.0, 2.0, 3.0, 2.0])
-        self.assertEqual(mean, 2.5)
+        self.assertEqual(all_residuals, [3.0, 1.0, 4.0, 2.0])
+        self.assertEqual(mean, np.mean([3.0, 1.0, 4.0, 2.0]))
 
     def test_evaluate_array_r2_accuracy(self):
         true = np.array([[10, 20, 30, 40, 50], [60, 70, 80, 90, 100]])
