@@ -1,5 +1,6 @@
 import unittest
 
+import torch
 from torch import Tensor
 from lightwood.encoder.image import Img2VecEncoder
 import os
@@ -26,3 +27,16 @@ class TestImg2VecEncoder(unittest.TestCase):
         # NOTE: this will break when it will possible to choose different
         # encoding models.
         self.assertEqual(encoded_images_tensor.size(1), 512)
+
+    def run_test_encoder_on_device(self, device):
+        enc = Img2VecEncoder(device=device)
+        enc.prepare([], [])
+        self.assertEqual(enc.model.device, torch.device(device))
+        self.assertEqual(list(enc.model.parameters())[0].device.type, device)
+
+    def test_encoder_on_cpu(self):
+        self.run_test_encoder_on_device('cpu')
+
+    @unittest.skipIf(not torch.cuda.is_available(), 'CUDA unavailable')
+    def test_encoder_on_cuda(self):
+        self.run_test_encoder_on_device('cuda')
