@@ -2,7 +2,7 @@ import copy
 import logging
 import torch
 import unittest
-from lightwood.encoder.time_series import TimeSeriesEncoder
+from lightwood.encoder.time_series.rnn import TimeSeriesEncoder
 from lightwood.encoder.time_series.helpers.transformer_helpers import TransformerEncoder, len_to_mask, get_chunk
 import pandas as pd
 
